Learn R Programming

tcgsaseq (version 2.0.5)

tcgsaseq: tcgsaseq: a package to perform Time-course Gene Set Analysis and General Gene-Wise Analysis of RNA-seq data

Description

Analysis of RNA-seq data with variance component score test accounting for data heteroscedasticity through precision weights.

Arguments

Details

Package: tcgsaseq
Type: Package
Version: 2.0.4
Date: 2020-09-10
License: GPL-2

The two main functions of the tcgsaseq package are varcompseq and tcgsa_seq.

References

Agniel D & Hejblum BP (2017). Variance component score test for time-course gene set analysis of longitudinal RNA-seq data, Biostatistics, 18(4):589-604. 10.1093/biostatistics/kxx005. arXiv:1605.02351.