powered by
Adapted from the supplementary material from Law et al.
data_sim_voomlike( seed = NULL, maxGSsize = 400, minGSsize = 30, beta = 0, do_gs = TRUE, longitudinal = TRUE, mixed_hypothesis = FALSE, n = 18, nindiv = 6, ntime = 3, propH1 = 0.1 )
Law, C. W., Chen, Y., Shi, W., & Smyth, G. K. (2014). voom: Precision weights unlock linear model analysis tools for RNA-seq read counts. Genome Biology, 15(2), R29.
# NOT RUN { set.seed(123) data_sims <- data_sim_voomlike(maxGSsize = 300) data_sims <- data_sim_voomlike(maxGSsize = 300, beta = 1.8) # }
Run the code above in your browser using DataLab